###############################################################################
# DonationPage.pm                                                             #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
# Written by Derek Barnstorm                                                  #
# Updated for 2.7.00 by D.A.Rorabaugh                                         #
###############################################################################
use strict;
use warnings;
use CGI::Carp qw(fatalsToBrowser);
our $VERSION = '2.7.00';

our $donationpagepmver = 'YaBB 2.7.00 $Revision: 0.9 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

## languages ##
our ( %donate_txt, %cur_sign );
## paths ##
our ( $vardir, $langdir, $modimgurl, $scripturl, );
## settings ##
our ( $lang, $en_donationpage );
## system ##
our (
    $action_area,   $date,         $iamguest, $language,
    $username,      $mbname,       $yymain,   $yymycharset,
    $yysetlocation, $yynavigation, $yytitle,  %FORM,
    %INFO,          %mod_list,     $uid,      %link,
);

## local ##
our ( $donation_content, $donation_id, $donation_currency, $donation_amount,
    $donation_header_color, $donation_border_color, $donation_bg_color );

if ( -e ("$vardir/Mods/DonationPage.txt") ) {
    require "$vardir/Mods/DonationPage.txt";
}
if ( !$en_donationpage || ( $iamguest && $en_donationpage != 1 ) ) {
    fatal_error('not_allowed');
}

load_language('Mods/DonationPage');

sub Donate {
    my $use_lang = $language ? $language : $lang;
    my $donation_file = "$langdir/English/Mods/donate.txt";
    if ( -e "$langdir/$use_lang/Mods/donate.txt" ) {
        $donation_file = "$langdir/$use_lang/Mods/donate.txt";
    }
    elsif ( -e "$langdir/$lang/Mods/donate.txt" ) {
        $donation_file = "$langdir/$lang/Mods/donate.txt";
    }
    elsif ( -e "$langdir/English/Mods/donate.txt" ) {
        $donation_file = "$langdir/English/Mods/donate.txt";
    }
    our ($FILE);
    if ( -e $donation_file ) {
        fopen( 'FILE', '<', $donation_file );
        $donation_content = <$FILE>;
        fclose('FILE');
    }

    $donation_content ||= q{};
    from_html($donation_content);
    to_chars($donation_content);
    if ($donation_content) {
        $donation_content =
          qq~            <td class="windowbg vtop">$donation_content</td>
        </tr><tr>~;
    }

    my $donator_name = $donate_txt{'15'};
    my $donator      = $donate_txt{'15'};
    if ($iamguest) {
        $donator_name = $donate_txt{'15'};
        $donator      = $donate_txt{'15'};
    }
    else {
        {
            no strict qw(refs);
            $donator_name = qq~$link{$username}~;
            $donator      = qq~${$uid.$username}{'realname'}~;
        }
    }

    $yymain .= << "PAGE";
<form action="https://www.paypal.com/cgi-bin/webscr" method="post" name="donate" onsubmit="return CheckDonationField();">
    <table class="tabtitle pad_4px" style="width:50%; margin:0 auto">
        <tr>
            <th style="padding-left:1%"><img src="$modimgurl/donate.gif" alt="" /> $donate_txt{'01'} $mbname</th>
        </tr>
    </table>
    <table class="bordercolor pad_4px cs_thin" style="width:50%; margin:0 auto">
$donation_content
            <td class="windowbg2 center" style="font-weight: bold;">
                <div>
                    <label>$donate_txt{'02'}:</label> $donator_name
                </div>
                <div>
                    <label for="donation_amount">$donate_txt{'03'}:</label>
                    $cur_sign{$donation_currency}<input type="text" name="amount" id="donation_amount" size="10" value="$donation_amount" onfocus="txtInFields(this, '$donation_amount');" onblur="txtInFields(this, '$donation_amount')" /> ($donation_currency)
                </div>
            </td>
        </tr><tr>
            <td class="catbg center" height="50" style="height:50px">
                <input type="hidden" name="cmd" value="_donations" />
                <input type="hidden" name="business" value="$donation_id" />
                <input type="hidden" name="item_name" value="$mbname - $donate_txt{'05'} $donator" />
                <input type="hidden" name="return" value="$scripturl?action=donationreceived" />
                <input type="hidden" name="cancel_return" value="$scripturl" />
                <input type="hidden" name="currency_code" value="$donation_currency" />
                <input type="hidden" name="cpp_headerback_color" value="$donation_header_color" />
                <input type="hidden" name="cpp_headerborder_color" value="$donation_border_color" />
                <input type="hidden" name="cpp_payflow_color" value="$donation_bg_color" />
                <input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif" alt="$donate_txt{'06'}" />
            </td>
        </tr>
    </table>
</form>
<script type="text/javascript">
function CheckDonationField() {
if (document.donate.donation_amount.value == '') {
    alert("$donate_txt{'07'}");
    document.donate.donation_amount.focus();
    return false;
}
return true;
}
</script>
PAGE

    $yytitle      = "$donate_txt{'01'} $mbname";
    $yynavigation = qq~&rsaquo; $donate_txt{'04'}~;
    template();
    return;
}

sub DonationReceived {

    $yymain .= << "PAGE";
    <table class="tabtitle pad_4px" style="width:50%; margin:0 auto">
        <tr>
            <th style="padding-left:1%"><img src="$modimgurl/donate.gif" alt="" /> $donate_txt{'08'}</th>
        </tr>
    </table>
    <table class="bordercolor pad_4px cs_thin" style="width:50%; margin:0 auto">
        <tr>
            <td class="titlebg center">
                $donate_txt{'09'} $mbname!
            </td>
        </tr><tr>
            <td class="windowbg2" style="padding:10px">
                $donate_txt{'10'}<br /><br />
                $donate_txt{'11'} $mbname $donate_txt{'12'}
            </td>
        </tr><tr>
            <td class="windowbg center">
                &bull; <a href="$scripturl">$donate_txt{'13'}</a>
            </td>
        </tr>
</table>
PAGE

    $yytitle      = "$donate_txt{'08'}";
    $yynavigation = qq~&rsaquo; $donate_txt{'14'}~;
    template();
}

1;
